Wisconsin Court System -

skip navigation
contact the court
directories
employment
news

###### Wisconsin Court System

- about the courts
- case search
- opinions
- rules
- forms
- services
- eFile / eCourts
- publications

overview supreme court court of appeals circuit courts municipal courts administrative offices committees and boards programs educational resources history
circuit court supreme court pending supreme court and
court of appeals
supreme court court of appeals
supreme court circuit court
circuit court court of appeals office of lawyer regulation board of bar examiners
for the public for jurors for attorneys for judges for commissioners for interpreters for volunteers for veterans
pay fees/fines online forms assistant online juror services circuit court eFiling appellate court eFiling cle reporting
guides reports fees and forfeitures newsletters speeches statistics

# Supreme Court opinions

## Search for opinions and dispositional orders - Results

Below is the list of opinions that match your search criteria. Electronic opinions are made available in PDF format. Published opinions are subject to further editing and modification. The final version will appear in the bound volume of the official reports.

To download multiple opinions, select all of the files you wish to download, go to the end of the list and click the download marked files button. All files will be compressed into a self-extracting exe file that you can download, or immediately unzip, to the location you specify.

Page 1 of 1 Search again

Release date | Docket number | Caption | Select/view
Oct 08, 2015 | 2015AP000578-D | Office of Lawyer Regulation v. James T. Runyon | PDF
Oct 08, 2015 | 2013AP002742-D | Office of Lawyer Regulation v. Thomas O. Mulligan | PDF

Page 1 of 1 Search again

Back to Supreme Court opinions